@@ -37,6 +37,7 @@ _SEARCH_PARAMETERS = {
     'set_text': ['setText', [str, None]],
     'backend_set': ['backendSet', [str, None]],
     'has_introduction': ['hasIntroduction', [bool, None]],
+    'backendIntroduction': ['backendIntroduction', [int, None]],
     'introduction_chapter': ['introductionChapter', [str, None]],
     'introduction_season': ['introductionSeason', [str, None]],
     'has_small_icon': ['hasSmallIcon', [bool, None]],
@@ -45,6 +46,10 @@ _SEARCH_PARAMETERS = {
     'has_variants': ['hasVariants', [bool, None]],
     'has_gameplay_tags': ['hasGameplayTags', [bool, None]],
     'gameplay_tag': ['gameplayTag', [str, None]],
+    'has_meta_tags': ['hasMetaTags', [bool, None]],
+    'meta_tag': ['metaTag', [str, None]],
+    'has_dynamic_pak_id': ['hasDynamicPakId', [bool, None]],
+    'dynamic_pak_id': ['dynamicPakId', [str, None]],
     'added': [None, [datetime.datetime, None]],
     'added_since': ['addedSince', [datetime.datetime, None]],
     'unseen_for': ['unseenFor', [int, None]],
